Core identifier types, available without feature gates.
AgentId and MemoryId are defined here so they can be used by the agent runtime regardless of whether the memory feature is enabled.
AgentId
MemoryId
memory